#
# spec file for package mayavi
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         X_display  ":98"
Name:           mayavi
Version:        4.5.0
Release:        3.80
Summary:        3D visualization of scientific data in Python
License:        BSD-3-Clause and EPL-1.0 and LGPL-2.0+ and LGPL-3.0+
Group:          Productivity/Scientific/Other
Url:            https://github.com/enthought/mayavi
Source0:        https://files.pythonhosted.org/packages/source/m/mayavi/mayavi-%{version}.tar.gz
Source1:        mayavi.desktop
Source2:        tvtk_doc.desktop
BuildRequires:  R-base-devel
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  python3-Sphinx
BuildRequires:  python3-apptools
BuildRequires:  python3-configobj
BuildRequires:  python3-devel
BuildRequires:  python3-envisage >= 3.0
BuildRequires:  python3-numpy-devel >= 1.0.1
BuildRequires:  python3-qt5
BuildRequires:  python3-setuptools
BuildRequires:  python3-traits >= 3.0
BuildRequires:  python3-traitsui >= 3.0
BuildRequires:  python3-vtk >= 5.0
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       python3-tvtk == %{version}
Requires:       python3-apptools
Requires:       python3-qt5
Requires:       python3-setuptools
Provides:       python3-mayavi = %{version}

%description
Mayavi seeks to provide easy and interactive visualization of 3-D 
data. It offers:

 * An (optional) rich user interface with dialogs to interact with
   all data and objects in the visualization.
 * A simple and clean scripting interface in Python, including
   one-liners, or an object-oriented programming interface. Mayavi
   integrates seamlessly with numpy and scipy for 3D plotting and can
   even be used in IPython interactively, similarly to Matplotlib.
 * The power of the VTK toolkit, harnessed through these interfaces,
   without forcing you to learn it.

Additionally Mayavi is a reusable tool that can be embedded in your
applications in different ways or combined with the Envisage
application-building framework to assemble domain-specific tools.

Part of the Enthought Tool Suite (ETS).

%package -n python3-tvtk
Summary:        A python3-traits enabled version of python3-vtk
Group:          Productivity/Scientific/Other
Requires:       python3-numpy >= 1.0.1
Requires:       python3-traits >= 3.0
Requires:       python3-traitsui >= 3.0
Requires:       python3-vtk >= 5.0
Recommends:     python3-configobj
Recommends:     python3-envisage >= 3.0
Recommends:     python3-wxWidgets >= 2.8

%description -n python3-tvtk
TVTK wraps VTK objects to provide a convenient, Pythonic API, while
supporting Traits attributes and NumPy/SciPy arrays. TVTK is
implemented mostly in pure Python, except for a small extension module.

Developers typically use TVTK to write Mayavi modules, and then use
Mayavi to interact with visualizations or create applications. 

Part of the Enthought Tool Suite (ETS).

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Requires:       %{name} == %{version}

%description doc
Documentation files for the package %{name}

%package -n python3-tvtk-doc
Summary:        Documentation for python3-tvtk
Group:          Documentation/HTML
Requires:       python3-tvtk == %{version}

%description -n python3-tvtk-doc
Documentation files for the package python3-tvtk.

%prep
%setup -q -n mayavi-%{version}
rm -rf Mayavi.egg-info

# wrong-file-end-of-line-encoding
sed -i 's|\r||' examples/mayavi/data/room_vis.wrl

# spurious-executable-perm
chmod -x mayavi/tests/data/cellsnd.ascii.inp

%build
export LANG=en_US.UTF-8
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10
export CFLAGS="%{optflags}"
%python3_build

%install
export LANG=en_US.UTF-8
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10
%python3_install

# examples and integrationtests are not installed by the build system
# Manually install examples and integrationtests in python3_sitearch
mkdir -p %{buildroot}%{python3_sitearch}/mayavi/examples
cp -R examples/mayavi/* %{buildroot}%{python3_sitearch}/mayavi/examples/
mkdir -p %{buildroot}%{python3_sitearch}/mayavi/integrationtests
cp -R integrationtests/mayavi/* %{buildroot}%{python3_sitearch}/mayavi/integrationtests/
mkdir -p %{buildroot}%{python3_sitearch}/tvtk/examples
cp -R examples/tvtk/* %{buildroot}%{python3_sitearch}/tvtk/examples/

# Remove shebang from .py files in examples and integrationtests
# as they are not supposed to be executed
for i in %{buildroot}%{python3_sitearch}/{mayavi,tvtk}/examples/*.py;
do
sed -i -e '/^#!\//, 1d' $i;
done
for i in %{buildroot}%{python3_sitearch}/{mayavi,tvtk}/examples/*/*.py;
do
sed -i -e '/^#!\//, 1d' $i;
done
for i in %{buildroot}%{python3_sitearch}/mayavi/integrationtests/*.py;
do
sed -i -e '/^#!\//, 1d' $i;
done
%if 0%{?suse_version} > 1320
for i in %{buildroot}%{python3_sitearch}/mayavi/html/_downloads/*.py;
do
sed -i -e '/^#!\//, 1d' $i;
done
%endif

mkdir -p %{buildroot}/%{_mandir}/man1/
mv docs/mayavi2.man %{buildroot}/%{_mandir}/man1/%{name}.1
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/
install -p -m 644 ./docs/source/mayavi/images/mayavi2-48x48.png \
   %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/mayavi2.png
install -p -m 644 ./docs/source/mayavi/images/mayavi2-48x48.png \
   %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/tvtk_doc.png

chmod a+x %{buildroot}%{python3_sitearch}/mayavi/scripts/mayavi2.py
chmod a+x %{buildroot}%{python3_sitearch}/mayavi/tests/runtests.py
chmod a+x %{buildroot}%{python3_sitearch}/tvtk/setup.py

# REMOVE BYTECODES NOT ACCOMPANIED BY SOURCE CODE
rm -fr %{buildroot}%{python3_sitearch}/tvtk/plugins/scene/__init__.py{c,o}
rm -fr %{buildroot}%{python3_sitearch}/tvtk/plugins/browser/__init__.py{c,o}
rm -fr %{buildroot}%{python3_sitearch}/tvtk/plugins/scene/ui/__init__.py{c,o}
rm -fr %{buildroot}%{python3_sitearch}/tvtk/tools/__init__.py{c,o}
rm -fr %{buildroot}%{python3_sitearch}/tvtk/pipeline/__init__.py{c,o}
rm -fr %{buildroot}%{python3_sitearch}/tvtk/plugins/__init__.py{c,o}
rm -fr %{buildroot}%{python3_sitearch}/tvtk/version.py{c,o}

# REMOVE UNNEEDED HIDDEN FILE
rm -fr %{buildroot}%{python3_sitearch}/{tvtk,mayavi}/html/.buildinfo

%suse_update_desktop_file -i mayavi
%suse_update_desktop_file -i tvtk_doc

rm -r docs/build/{tvtk,mayavi}/html/.buildinfo
sed -i 's/\r$//' docs/build/tvtk/html/objects.inv
mkdir -p %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}%{_docdir}/python3-tvtk
cp -r docs/build/mayavi/html %{buildroot}%{_docdir}/%{name}/
cp -r docs/build/tvtk/html %{buildroot}%{_docdir}/python3-tvtk/

%fdupes %{buildroot}%{_docdir}/%{name}/
%fdupes %{buildroot}%{_docdir}/python3-tvtk/
%fdupes %{buildroot}%{python3_sitearch}/mayavi
%fdupes %{buildroot}%{python3_sitearch}/tvtk
%fdupes %{buildroot}%{_datadir}/icons/

python3 -m compileall -d %{python3_sitearch} %{buildroot}%{python3_sitearch}/mayavi
python3 -O -m compileall -d %{python3_sitearch} %{buildroot}%{python3_sitearch}/mayavi
%fdupes %{buildroot}%{python3_sitearch}/mayavi

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc LICENSE*.txt image_LICENSE*.txt README*.*
%{_bindir}/mayavi2
%{_mandir}/man1/%{name}.1.gz
%{_datadir}/applications/mayavi.desktop
%{python3_sitearch}/mayavi/
%{python3_sitearch}/mayavi-%{version}-py*.egg-info
%exclude %{_docdir}/%{name}/html/

%files -n python3-tvtk
%defattr(-,root,root,-)
%doc LICENSE*.txt image_LICENSE*.txt README*.*
%{_bindir}/tvtk_doc
%{_datadir}/applications/tvtk_doc.desktop
%{_datadir}/icons/hicolor
%{python3_sitearch}/tvtk/
%exclude %{_docdir}/python3-tvtk/html/

%files doc
%defattr(-,root,root,-)
%doc LICENSE*.txt image_LICENSE*.txt README*.*
%{_docdir}/%{name}/html/

%files -n python3-tvtk-doc
%defattr(-,root,root,-)
%doc LICENSE*.txt image_LICENSE*.txt README*.*
%{_docdir}/python3-tvtk/html/

%changelog
* Fri Aug 25 2017 toddrme2178@gmail.com
- Switch to python3
- Update to Mayavi 4.5.0
  + Enhancements
  * Jupyter notebook support!  Adds support for displaying Mayavi images or
    x3d scenes on the notebook. The x3d scenes allow one to fully interact
    with the scene in the notebook.  More documentation is available at
    :ref:`jupyter_notebook`.
  * Adds support for recording movies and animating timesteps.  See
    :ref:`animating_a_timeseries` and :ref:`animating_a_visualization` for
    more details.
  * Updated LUTs to include new matplotlib colorschemes, this includes the
    new viridis colormap.
  + Fixes
  * Fix several bugs, `#397 <https://github.com/enthought/mayavi/issues/397>`_
    where PDF files were not saved properly. Fix issues with ``tvtk.visual``
    and add many tests for it, this fixes `#387
    <https://github.com/enthought/mayavi/issues/387>`_.  Refactor the save
    screenshot dialog popups.  Fix problem with the picker point not showing
    when "p" is pressed on the scene.
  * Python 3 fixes for the jupyter notebook support.
  * Fixes `#388 <https://github.com/enthought/mayavi/issues/388>`_ where
    tubes were not showing on protein demo.
  * Add additional save options.
  * Fixes `#403 <https://github.com/enthought/mayavi/issues/403>`_ where the
    image plane widget and volume modules were broken.
  * Debug info on code gen for wrapper generation.
  * BUG: Fix slice unstructured grid module.
  * Fix typo in readme.
  * update codecov configuration
  * Documentation for QString API failure.
  * Fixes incorrect signature of ``EnvisageEngine.new_scene``.
  * Fix for unexpected test code.
  * Fix "_p_void" values in TVTK with VTK 6.x
  * Fix failing test for custom import in some circumstances
  * Removes ``array_ext.so/pyd`` on clean
  * Check if test successful with the appropriate filename.
  * Unicode trait handling for those vtk methods returning unicode data
  * ENH: Nice load pylab_luts.pkl
  * Document object identity behavior matching VTK
  * Revert "Fix savefig size and black image"
  * Added setup.py documentation for Qt requirements
  * Add VTK 6.3 and VTK 7 to travis ci
  * Fix traitsdoc setup and compliance with py3
  * Import and integer division in python3
  * Fix texture on ``mlab.surf``, issue `#211 <https://github.com/enthought/mayavi/issues/211>`_.
  * Fixes Quiver3d Failure with different argument types
  * Fix Text3D in VTK 6.0+
  * Fix savefig size and black image
  * Fix for exception when modifying extents
  * Suppresses test for VTK 6.2 (solves appVeyor random failure)
  * Forces pipeline update when LUT changes
  * Fix for test failure on mayavi -t
  * Enforce ordering of attribute labels in VTKDataSource.
  * Apply has_attribute to the output in VTKFileReader
  * Replacing links to code. and svn.enthought.com
  * Fix Camera off-centered when loading saved visualization
  * Update to use new VTK pipeline where possible.  This fixes a number of
    issues with the pipeline was not updating properly.
  * Fix issue with ``mlab.move``
  * Fix issue `#302 <https://github.com/enthought/mayavi/issues/302>`_,
    segfault when savefig is called multiple times.
  * Fix get_engine behavior when backend is changed again.
* Mon Apr 25 2016 badshah400@gmail.com
- Rename python-mayavi to mayavi.
- Avoid some rpmlint warnings by removing shebangs from
  non-executable doc files.
- Avoid rpmlint warnings by removing python byte-codes where they
  are not accompanied by the source code.
- Drop an unneeded hidden file to avoid rpmlint warning.
* Wed Mar 16 2016 stecue@gmail.com
- updated to 4.4.4
  * fixed compilation problem with vtk 7.0.0
* Mon Sep  7 2015 toddrme2178@gmail.com
- Update to 4.4.3
  * Enhancements
  - Update the readme fixing dead links
  - Use new Travis CI containers for faster builds
  - Add CI tests on Windows using Appveyor
  * Fixes
  - Remove reference cycles from various objects to fix memory leaks. Add
    unit test that provides an API to test garbage collection.
  - Fix the LUT manager to select the correct lut mode for QT backend
  - Use the python-wxtool package to speed up Travis CI build
  - Fix TVTK wrapper to allow look up with long keys for Points
  - Fix glyph to handle the masking of input points
  - Update the docs with known bugs, issues list and describe the PR
    workflow on github for development and documentation.
  - Fix TVTK wrapper to update number of cells when a cell is inserted in a
    VTK cell array
  - Fix VKTFileReader to update output when using standalone
  - Fix the sdist command
- Update to 4.4.2
  * Enhancements
  - Upgrade the VTK parser to add support for VTK 6.2.
- Update to 4.4.1
  * Fixes
  - Fix trackpad scrolling to zoom in/out smoothly on OS X.
- Update to 4.4.0
  * Enhancements
  - Add function to set data at input port, add stanford (bunny,
    dragon, lucy) examples, and use new volume mapper for new pipeline.
  - Upgrade to VTK 6.0 with VTK's new pipeline.
  * Fixes
  - Support dynamic dimensions in array source.
  - Fix MRI brain data URL.
  - More fixes for connection topology, information request and tube filter
    after upgrading to new pipeline.
  - Handle the non-Latin-1 keypresses.
  - Prevent ndarray comparisions with None.
  - Fix the trait error raised when the threshold range is updated.
  - Update installation documentation links.
  - Fix integration tests after upgrade to VTK's new pipeline.
* Mon Oct 13 2014 toddrme2178@gmail.com
- Updated source to pypi url.
* Thu Feb  6 2014 toddrme2178@gmail.com
- Update to 4.3.1
  - Bugfixes
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 4.3.0
  - NEW: Adding a Qt version of the gradient editor. With this, all of
    Mayavi's UI should be usable on Qt.
  - Fixed bug with incorrectly tiled snapshots while using savefig.
  - BUG: Qt: fix crashing full-screen-mode.  Fixed segfault when you click on
    full-screen and press escape/q/e.
- Update to 4.2.1
  - ENH: Add null engine to mlab.pipeline.open.
* Sun Dec  9 2012 jw@suse.com
- Requires: python-distribute for pkg_resources.
* Mon Nov 19 2012 jmatejek@suse.com
- change Requires: python-traitsGUI to python-traitsui
  (bnc#781367)
* Fri May 25 2012 toddrme2178@gmail.com
- Fix BuildRequires, Requires, and Recommends naming
* Tue May 22 2012 badshah400@gmail.com
- Update to version 4.2.0: No detailed changelog available.
- The example and integrationtests files are not installed by the
  build system any more. They are manually copied into the
  directories %%python_sitearch/mayavi/ and %%python_sitearch/tvtk/
  as applicable.
* Wed Jan 11 2012 toddrme2178@gmail.com
- Cleaned up spec file
- Renamed package from python-Mayavi to python-mayavi to match module name
- Split tvtk package
* Tue Nov  1 2011 ocefpaf@gmail.com
- Fixed build for vtk 5.8
* Sat Jun 25 2011 ocefpaf@yahoo.com.br
- updated to release 1562 ; version 4.0.0
* Wed Jun 15 2011 ocefpaf@yahoo.com.br
- updated to release 1552 ; version 3.5.0
* Sun May  1 2011 ocefpaf@yahoo.com.br
- updated to release 1521
* Sat Apr 23 2011 ocefpaf@yahoo.com.br
- updated to release 1519
* Sat Apr  9 2011 ocefpaf@yahoo.com.br
- updated to release 1514
* Sun Apr  3 2011 ocefpaf@yahoo.com.br
- updated to release 1513
* Sat Mar 12 2011 ocefpaf@yahoo.com.br
- updated revision 1506
* Sat Feb 19 2011 ocefpaf@yahoo.com.br
- updated revision 1505
* Sat Feb  5 2011 ocefpaf@yahoo.com.br
- updated revision 1497
* Sun Jan 30 2011 ocefpaf@yahoo.com.br
- updated to svn revision 26451
* Wed Dec 29 2010 ocefpaf@yahoo.com.br
- updated to svn revision 26178
* Sat Dec 18 2010 ocefpaf@yahoo.com.br
- updated to svn release 26099
* Sat Nov 20 2010 ocefpaf@yahoo.com.br
- updated to svn release 26037
* Sat Nov 13 2010 ocefpaf@yahoo.com.br
- updated to svn 25993
* Sun Oct 31 2010 ocefpaf@yahoo.com.br
- updated to svn 25932
* Sun Oct 24 2010 ocefpaf@yahoo.com.br
- updated to svn 25905
* Tue Oct 19 2010 highwaystar.ru@gmail.com
- updated to version 3.4.0
* Wed Jun 30 2010 highwaystar.ru@gmail.com
- updated to version 3.3.2
* Thu Apr 22 2010 highwaystar.ru@gmail.com
- initial release for openSUSE
- spec imported from Fedora
